.. cumulusci documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to CumulusCI's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   why_cumulusci
   install
   tutorial
   features
   robotframework
   robotframework-tutorial
   robotframework-debugger
   bulk_data
   cookbook
   cumulusci_flow
   usage

.. toctree::
   :maxdepth: 1

   tasks
   history
   authors
   contributing
   api_reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
